@@ -24,7 +24,7 @@
 #include "gck.h"
 #include "gck-mock.h"
 
-#include "pkcs11.h"
+#include <p11-kit/pkcs11.h>
 #include "pkcs11i.h"
 
 #include <glib.h>
